@@ -1,16 +1,18 @@
 package LEOCHARRE::Test;
-
-use Exporter;
+use strict 'vars';
+use Test::Builder::Module;
 use vars qw(@EXPORT @ISA $VERSION $PART_NUMBER);
-use strict;
-no warnings 'redefine';
-@EXPORT = qw(ok_part);
-$VERSION = sprintf "%d.%02d", q$Revision: 1.2 $ =~ /(\d+)/g;
-@ISA = qw/Exporter/;
+@EXPORT = qw(ok_part ok test_is_interactive);
+$VERSION = sprintf "%d.%02d", q$Revision: 1.3 $ =~ /(\d+)/g;
+@ISA    = qw(Test::Builder::Module);
 use Carp;
 
 
+my $CLASS = __PACKAGE__;
 
+sub ok ($;$) {
+    $CLASS->builder->ok(@_);
+}
 sub ok_part {
    my $msg = shift;
    $msg ||='';
@@ -21,6 +23,9 @@ sub ok_part {
 }
 
 
+sub test_is_interactive { 
+   return -t STDIN && -t STDOUT;
+}
 
 
 
@@ -40,7 +45,18 @@ LEOCHARRE::Test - personal testing subs
 
 All are exported.
 
-=head1 ok_part()
+=head2 ok()
+
+Like Test::Simple
+
+=head2 ok_part()
 
 Optional arg is message, helps read test output.
 Just a separator.
+
+=head2 test_is_interactive()
+
+Returns boolean. If run from a terminal, returns true, if from cpan, false.
+
+
+
